@@ -227,6 +227,7 @@ class TaskTracks(Task):
             s = template.stream({
                 'gdata': gdata,
                 'default_tile': args.gpx_defaulttile,
+                'default_track': args.gpx_defaulttrack,
                 'tracks': self.outputs,
             })
             s.dump(htmlfile)
@@ -306,6 +307,8 @@ def __main__():
                         help='Thumbnails: Hide the "play" overlay image. Defaults to an internal one, based on size')
     parser.add_argument('--gpx-defaulttile', default='OpenStreetMap',
                         help='Tracks: The default tile data key (see `static/gpx/multiple.js`). Defaults to %(default)s')
+    parser.add_argument('--gpx-defaulttrack', type=int, default=None,
+                        help='Tracks: The default track to select.')
     parser.add_argument('--insecure', action='store_true',
                         help='Do not use any security-related features on the generated files. Useful for tests on `localhost`')
     parser.add_argument('-v', '--verbose',
