@@ -18,7 +18,8 @@ function activateMedia(media, simplify=true, new_history=false) {
 	element_video.classList.add("hidden");
 	var mime = media.dataset['mime'];
 	if (mime.startsWith('image')) {
-		element_image.src = url;
+		element_image.src = ''; // Hide the old image
+		element_image.src = url;  // Show the new one
 		element_image.classList.remove('hidden');
 	}
 	else if (mime.startsWith('video')) {
@@ -89,6 +90,9 @@ function closeFullscreen(e) {
 	console.log("Close the FullScreen media");
 	document.getElementById('fullscreen').classList.add("hidden");
 
+	// Hide the old image
+	var element_image = document.getElementById('fullscreen-picture-image');
+	element_image.src = '';
 	// Pause video
 	var element_video = document.getElementById('fullscreen-picture-video');
 	element_video.load()
